==> 0.13.0.tar.gz: lib/src/omnibus.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by a MIT-style license
// that can be found in the LICENSE file.

part of omnibus;

/// Omnibus controller
///
/// This class manages a single Omnibus context. You should bind messasage
/// handlers to the Omnibus using [bind]. You can publish messages using
/// [publishEvent] and [publishRequest]. You cannot unbind handlers or
/// dynamically change their filter values and you shouldn't have to. A handler
/// should be a stateless, independant part of your program that uses a storage
/// backend only to store data and not to store state. Changing the filter or
/// unbinding the handler is a state change in some sense. Handlers that are
/// only used temporarily should be replaced by more generalized handlers that
/// exist permanently.
class Omnibus {
  /// Event handlers
  _EventHandlerPool _eventHandlers = new _EventHandlerPool();

  /// Request handlers
  _RequestHandlerPool _requestHandlers = new _RequestHandlerPool();

  /// Bind handler
  void bind(OmnibusHandler handler) {
    if (handler != null) {
      if (handler.type == OmnibusMessageType.event) {
        _eventHandlers.insert(handler);
      } else {
        _requestHandlers.insert(handler);
      }
    } else {
      throw new ArgumentError.notNull('handler');
    }
  }

  /// Publish OmnibusEvent
  ///
  /// This method runs in the future and all handlers are executed
  /// asynchronously.
  Future publishEvent(OmnibusEvent event) {
    return _eventHandlers.publish(event);
  }

  /// Alias for [publishEvent]
  Future event(OmnibusEvent event) => publishEvent(event);

  /// Publish OmnibusRequest
  ///
  /// This method runs in the future and all handlers are executed
  /// asynchronously.
  Future<OmnibusResponses> publishRequest(OmnibusRequest request) {
    return _requestHandlers.publish(request);
  }

  /// Alias for [publishRequest]
  Future<OmnibusResponses> request(OmnibusRequest request) =>
      publishRequest(request);
}

==> 0.15.1.tar.gz: lib/src/omnibus.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by a MIT-style license
// that can be found in the LICENSE file.

part of omnibus;

/// Omnibus controller
///
/// This class manages a single Omnibus context. You should bind messasage
/// handlers to the Omnibus using [bind]. You can publish messages using
/// [publishEvent] and [publishRequest]. You cannot (yet) unbind handlers or
/// dynamically change their filter values. Handlers that are only used
/// temporarily should be replaced by more generalized handlers that exist
/// permanently.
class Omnibus {
  /// Event handlers
  _EventHandlerPool _eventHandlers = new _EventHandlerPool();

  /// Request handlers
  _RequestHandlerPool _requestHandlers = new _RequestHandlerPool();

  /// Bind handler
  void bind(OmnibusHandler handler) {
    if (handler != null) {
      if (handler.type == OmnibusMessageType.event) {
        _eventHandlers.insert(handler);
      } else {
        _requestHandlers.insert(handler);
      }
    } else {
      throw new ArgumentError.notNull('handler');
    }
  }

  /// Publish OmnibusEvent
  ///
  /// This method runs in the future and all handlers are executed
  /// asynchronously.
  Future publishEvent(OmnibusEvent event) {
    return _eventHandlers.publish(event);
  }

  /// Alias for [publishEvent]
  Future event(OmnibusEvent event) => publishEvent(event);

  /// Publish OmnibusRequest
  ///
  /// This method runs in the future and all handlers are executed
  /// asynchronously.
  Future<OmnibusResponses> publishRequest(OmnibusRequest request) {
    return _requestHandlers.publish(request);
  }

  /// Alias for [publishRequest]
  Future<OmnibusResponses> request(OmnibusRequest request) =>
      publishRequest(request);
}
